@@ -10,4 +10,10 @@ class DeprecatedError(AttributeError):
 class ValidationError(ValueError):
     """
     Error validating the given inputs
+    """
+
+
+class ParamError(ValueError):
+    """
+    Error inserting collection
     """
\ No newline at end of file
